@@ -1,4 +1,4 @@
-/* Copyright (C) 2011-2018 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2011-2019 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -74,7 +74,7 @@ SieveEditor::~SieveEditor()
 void SieveEditor::slotAccepted()
 {
     Q_EMIT okClicked();
-    accept();
+    //Don't accept here we need to check script. If it's failed we don't close this editor otherwise we will lose data
 }
 
 void SieveEditor::slotCanceled()
