@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -38,7 +38,7 @@ public:
     void setUrl(const QUrl &url);
     void setIsActive(bool active);
 
-    bool canStart() const;
+    Q_REQUIRED_RESULT bool canStart() const;
     void start();
 
 Q_SIGNALS:
